# Changelog

## v1.3.9

- Responsive fine tuning.

## v1.3.2

- Improve text wrapping.

## v1.3.1

- Improve resizeable image.

## v1.3.0

- Add better text wrapping.

## v1.2.0

- Add image widget
- Demo changes. (still work in progress)
- Internal changes.

## v1.1.0

- Add text horizontal orientation in text widget.

## v1.0.8

- Make text color bindable

## v1.0.7

- Allow binding with starting value is None to select pulldown.

## v1.0.5

- MyPy typing fixes.

## v1.0.4

- Internal changes.
- Set section margin to 0

## v1.0.3

- Made minsize to -1 as it messes up grid.

## v1.0.2

- Fix binding issue on select widget.
## v1.0.1

- Fix pylint and mypy

## v1.0.0

- Releasing version 1.0.0

## v0.0.9

- Add "Section widget"
- Add better validation
- Add Events package for pub sub inside controller-view part.
- Add split/unsplit to splitview.
- Add Checkbox

## v0.0.8

- Add basic validation feedback.

## v0.0.6

- Make text label bindable.

## v0.0.5

- Add splitter window.
